==> nui_mini_program-0.0.3.tar.gz: lib/model/nui_miniprogram_module.dart <==
import 'dart:ui';
import 'package:nui_core/color/nui_color_util.dart';
import 'package:nui_core/data/nui_data_util.dart';
import 'package:nui_core/data/nui_ent.dart';
import 'package:nui_database/models/nui_database_entity.dart';
import 'package:nui_database/models/nui_database_entity_field.dart';
import 'package:nui_database/models/nui_database_entity_mapper.dart';
import 'package:nui_miniprogram_core/nui_miniprogram_interface.dart';

class NUIMiniProgramModule extends NUIDBEntity<NUIMiniProgramModule> with NUIMiniProgramInterface{
  NUIMiniProgramModule.empty();
  NUIMiniProgramModule({this.name, this.id, this.version, this.sourceUrl, this.description, this.brandColor, this.brandColorSecond, this.iconUrl});
  String name; //Name of the module
  String description; //Description of the module
  String id; //Unique id of the module
  String version; //Current version of the module
  String sourceUrl; //The source url to the zip file
  DateTime createdAt; //The first date of download
  DateTime updatedAt; //The last updated date
  String brandColor; //Hex format
  String brandColorSecond;
  String iconUrl;

  @override
  String getId() => id;

  @override
  String getName() => name;

  @override
  String getVersion() => version;

  @override
  Color getBrandColor() {
    if(!isNullOrEmpty(brandColor)){
      return colorFromHexString(brandColor);
    }
    return null;
  }

  @override
  String getIconUrl() {
    return iconUrl;
  }

  @override
  List<Color> getBrandColors() {
    if(isNullOrEmpty(brandColor) && isNullOrEmpty(brandColorSecond)) return null;

    List<Color> colors = [];
    if(!isNullOrEmpty(brandColor)){
      colors.add(colorFromHexString(brandColor));
    }
    if(!isNullOrEmpty(brandColorSecond)){
      colors.add(colorFromHexString(brandColorSecond));
    }
    return colors;
  }

  @override
  String toString(){
    return "id: $id, name: $name, version: $version, sourceUrl: $sourceUrl, brandColor: $brandColor, iconUrl: $iconUrl";
  }

  @override
  NUIEntMapper<NUIMiniProgramModule> mapper() => NUIMiniProgramModuleEnt();
}

class NUIMiniProgramModuleEnt extends NUIDBEntityMapper<NUIMiniProgramModule>{
  @override
  List<NUIDBField> dbFields() {
    return [
      NUIDBField<NUIMiniProgramModule>(name: "id", primaryKey: true, type: NUIEntType.STRING, setter: (data, value) => data.id = value, getter: (data) => data.id),
      NUIDBField<NUIMiniProgramModule>(name: "name", type: NUIEntType.STRING, setter: (data, value) => data.name = value, getter: (data) => data.name),
      NUIDBField<NUIMiniProgramModule>(name: "version", type: NUIEntType.STRING, setter: (data, value) => data.version = value, getter: (data) => data.version),
      NUIDBField<NUIMiniProgramModule>(name: "sourceUrl", type: NUIEntType.STRING, setter: (data, value) => data.sourceUrl = value, getter: (data) => data.sourceUrl),
      NUIDBField<NUIMiniProgramModule>(name: "brandColor", type: NUIEntType.STRING, setter: (data, value) => data.brandColor = value, getter: (data) => data.brandColor),
      NUIDBField<NUIMiniProgramModule>(name: "brandColorSecond", type: NUIEntType.STRING, setter: (data, value) => data.brandColorSecond = value, getter: (data) => data.brandColorSecond),
      NUIDBField<NUIMiniProgramModule>(name: "iconUrl", type: NUIEntType.STRING, setter: (data, value) => data.iconUrl = value, getter: (data) => data.iconUrl),
      NUIDBField<NUIMiniProgramModule>(name: "createdAt", type: NUIEntType.DATE, setter: (data, value) => data.createdAt = asDateTime(value), getter: (data) => data.createdAt),
      NUIDBField<NUIMiniProgramModule>(name: "updatedAt", type: NUIEntType.DATE, setter: (data, value) => data.updatedAt = asDateTime(value), getter: (data) => data.updatedAt),
    ];
  }

  @override
  String entityName() => "NUIMiniProgramModule";

  @override
  NUIMiniProgramModule newInstance() => NUIMiniProgramModule.empty();
}

==> nui_mini_program-0.0.33.tar.gz: lib/model/nui_miniprogram_module.dart <==
import 'dart:ui';
import 'package:nui_core/color/nui_color_util.dart';
import 'package:nui_core/data/nui_data_util.dart';
import 'package:nui_core/data/nui_ent.dart';
import 'package:nui_database/models/nui_database_entity.dart';
import 'package:nui_database/models/nui_database_entity_field.dart';
import 'package:nui_database/models/nui_database_entity_mapper.dart';
import 'package:nui_miniprogram_core/nui_miniprogram_interface.dart';

class NUIMiniProgramModule extends NUIDBEntity<NUIMiniProgramModule> with NUIMiniProgramInterface{
  NUIMiniProgramModule.empty();
  NUIMiniProgramModule({this.name, this.id, this.version, this.sourceUrl, this.remoteUrl, this.description, this.brandColor, this.brandColorSecond, this.iconUrl});
  String name; //Name of the module
  String description; //Description of the module
  String id; //Unique id of the module
  String version; //Current version of the module
  String sourceUrl; //The source url to the zip file
  String remoteUrl; //The remote url to the hosted mini program
  DateTime createdAt; //The first date of download
  DateTime updatedAt; //The last updated date
  String brandColor; //Hex format
  String brandColorSecond;
  String iconUrl;

  @override
  String getId() => id;

  @override
  String getName() => name;

  @override
  String getVersion() => version;

  @override
  Color getBrandColor() {
    if(!isNullOrEmpty(brandColor)){
      return colorFromHexString(brandColor);
    }
    return null;
  }

  @override
  String getIconUrl() {
    return iconUrl;
  }

  @override
  List<Color> getBrandColors() {
    if(isNullOrEmpty(brandColor) && isNullOrEmpty(brandColorSecond)) return null;

    List<Color> colors = [];
    if(!isNullOrEmpty(brandColor)){
      colors.add(colorFromHexString(brandColor));
    }
    if(!isNullOrEmpty(brandColorSecond)){
      colors.add(colorFromHexString(brandColorSecond));
    }
    return colors;
  }

  @override
  String toString(){
    return "id: $id, name: $name, version: $version, sourceUrl: $sourceUrl, brandColor: $brandColor, iconUrl: $iconUrl";
  }

  @override
  NUIEntMapper<NUIMiniProgramModule> mapper() => NUIMiniProgramModuleEnt();
}

class NUIMiniProgramModuleEnt extends NUIDBEntityMapper<NUIMiniProgramModule>{
  @override
  List<NUIDBField> dbFields() {
    return [
      NUIDBField<NUIMiniProgramModule>(name: "id", primaryKey: true, type: NUIEntType.STRING, setter: (data, value) => data.id = value, getter: (data) => data.id),
      NUIDBField<NUIMiniProgramModule>(name: "name", type: NUIEntType.STRING, setter: (data, value) => data.name = value, getter: (data) => data.name),
      NUIDBField<NUIMiniProgramModule>(name: "version", type: NUIEntType.STRING, setter: (data, value) => data.version = value, getter: (data) => data.version),
      NUIDBField<NUIMiniProgramModule>(name: "sourceUrl", type: NUIEntType.STRING, setter: (data, value) => data.sourceUrl = value, getter: (data) => data.sourceUrl),
      NUIDBField<NUIMiniProgramModule>(name: "remoteUrl", type: NUIEntType.STRING, setter: (data, value) => data.remoteUrl = value, getter: (data) => data.remoteUrl),
      NUIDBField<NUIMiniProgramModule>(name: "brandColor", type: NUIEntType.STRING, setter: (data, value) => data.brandColor = value, getter: (data) => data.brandColor),
      NUIDBField<NUIMiniProgramModule>(name: "brandColorSecond", type: NUIEntType.STRING, setter: (data, value) => data.brandColorSecond = value, getter: (data) => data.brandColorSecond),
      NUIDBField<NUIMiniProgramModule>(name: "iconUrl", type: NUIEntType.STRING, setter: (data, value) => data.iconUrl = value, getter: (data) => data.iconUrl),
      NUIDBField<NUIMiniProgramModule>(name: "createdAt", type: NUIEntType.DATE, setter: (data, value) => data.createdAt = asDateTime(value), getter: (data) => data.createdAt),
      NUIDBField<NUIMiniProgramModule>(name: "updatedAt", type: NUIEntType.DATE, setter: (data, value) => data.updatedAt = asDateTime(value), getter: (data) => data.updatedAt),
    ];
  }

  @override
  String entityName() => "NUIMiniProgramModule";

  @override
  NUIMiniProgramModule newInstance() => NUIMiniProgramModule.empty();
}
